@@ -1,4 +1,4 @@
-from .primitives import (parallel, scatter, pipeline, reduce, map, mapreduce, rank, size)
+from .primitives import (parallel, scatter, pipeline, stream, reduce, map, mapreduce, host, rank, size)
 from functools import partial
 from pipe import select, where
 from pydash import flatten, chunk, omit, get, filter_ as filter
@@ -12,6 +12,7 @@ __all__ = (
     'mapreduce',
     'reduce',
     'partial',
+    'stream',
     'select',
     'where',
     'flatten',
@@ -19,6 +20,7 @@ __all__ = (
     'omit',
     'get',
     'rank',
+    'host',
     'size',
     'filter'
 )
